package com.zhyc.module.sale.service;

import java.util.List;
import com.zhyc.module.sale.domain.SxSheepSale;

/**
 * 羊只销售记录Service接口
 *
 * @author ruoyi
 * @date 2025-08-19
 */
public interface ISxSheepSaleService {
    /**
     * 查询羊只销售记录
     *
     * @param id 羊只销售记录主键
     * @return 羊只销售记录
     */
    public SxSheepSale selectSxSheepSaleById(Long id);

    /**
     * 查询羊只销售记录列表
     *
     * @param sxSheepSale 羊只销售记录
     * @return 羊只销售记录集合
     */
    public List<SxSheepSale> selectSxSheepSaleList(SxSheepSale sxSheepSale);

    /**
     * 新增羊只销售记录
     *
     * @param sxSheepSale 羊只销售记录
     * @return 结果
     */
    public int insertSxSheepSale(SxSheepSale sxSheepSale);

    /**
     * 修改羊只销售记录
     *
     * @param sxSheepSale 羊只销售记录
     * @return 结果
     */
    public int updateSxSheepSale(SxSheepSale sxSheepSale);

    /**
     * 批量删除羊只销售记录
     *
     * @param ids 需要删除的羊只销售记录主键集合
     * @return 结果
     */
    public int deleteSxSheepSaleByIds(Long[] ids);

    /**
     * 删除羊只销售记录信息
     *
     * @param id 羊只销售记录主键
     * @return 结果
     */
    public int deleteSxSheepSaleById(Long id);

    /**
     * 【新增】根据耳号查询羊只信息
     * @param bsManageTags 耳号
     * @return 羊只信息
     */
    public SxSheepSale selectSheepInfoByTag(String bsManageTags);
}